#########################################################################
#########################################################################
#            Exploratory Analysis for "lagged" income: Balanced Panel   #  
#########################################################################
###########################################
##           Data preparation            ##
###########################################
Daten <- "P:/Syntax"
setwd(Daten)


####load required packages
library(psych)
library(sjPlot)
library(weights)
library(haven)
library(lubridate)
library(Weighted.Desc.Stat)
library(MASS)
library(mediation)
library(stargazer)
library(ggplot2)
library(tidyverse)
library(survey)
####read original SOEP data
###individual data set for 2018
#path_bip <- file.choose() # only the first time in your respective folder
path_bip <- "../Daten/SPSS_DE/raw/bip.sav" # important: you must have the working directory in a subfolder or a project 
data_bip <- data.frame(read_sav(path_bip))
###generated data for 2018
#path_bipgen <- file.choose()
path_bipgen <- "../Daten/SPSS_DE/raw/bipgen.sav"
data_bipgen <- data.frame(read_sav(path_bipgen))
###individual data set for 2019
#path_bjp <- file.choose() # only the first time in your respective folder
path_bjp <- "../Daten/v36_2019/SOEP-COREv36eu_SPSS_DE/SPSS_DE/raw/bjp.sav" # important: you must have the working directory in a subfolder or a project 
data_bjp <- data.frame(read_sav(path_bjp))
###generated data set for 2019
#path_bjpgen <- file.choose()
path_bjpgen <- "../Daten/v36_2019/SOEP-COREv36eu_SPSS_DE/SPSS_DE/raw/bjpgen.sav"
data_bjpgen <- data.frame(read_sav(path_bjpgen))

####ensuring that each person is only existing once in the dataframe
max(table(data_bip$pid))
max(table(data_bjp$pid))
max(table(data_bipgen$pid))
max(table(data_bjpgen$pid))

####select and rename variables
###individual data set for 2018
data_2018 <- data_bip[, c("pid", "sample1", "bipnr",
                          "bipbirthy", "bipbirthm", "sex", "bip_09_01", "bip_09_02",
                          "bip_09_03", "bip_09_04", "bip_09_05", "bip_09_06", "bip_14", "bip_15", "bip_16", "bip_29_02",
                          "bip_43", "bip_97_01", "bip_97_02", "bip_108", "bip_117_01", "bip_117_02", "bip_117_03","bip_191",
                          "bip_202_01")]

names(data_2018) <- c("pid", "sample1_2018", "bipnr",
                      "Geburtsjahr_2018", "Geburtsmonat_2018", "Gender_2018",  "narq_special_2018", "narq_attention_2018",
                      "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018", "impatient_2018", "risk_2018", "impusive_2018", "education_2018",
                      "employ_status_2018", "grossincome_2018", "netincome_2018", "sidejob_2018", "grossincome_sj1_2018", "grossincome_sj2_2018", "grossincome_sj3_2018","marital_status_2018",
                      "life_satisfaction_2018")

###generated data for 2018
data_gen2018 <- data_bipgen[, c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nation18", "bipsbil", "bipbbil01", "bipbbil02", "bibilzeit", 
                                "isced11_18", "labgro18", "impnet18", "kldb2010_18", "labnet18", "emplst18", "impgro18")]

names(data_gen2018) <- c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nationalit?t_2018", "Schulabschluss_2018", "berufl_Bildung_2018", "Hochschulabschluss_2018", "Bildungsjahre_2018", 
                         "isced11_2018", "Brutto_imput_2018", "Impflag_Netto_2018", "kldb2010_2018", "Netto_imput_2018", "emplstatus_2018", "Impflag_Brutto_2018")

###individual data set for 2019
data_2019 <- data_bjp[, c("pid", "bjpbirthy", "bjpbirthm", "sex")]

names(data_2019) <- c("pid", "Geburtsjahr_2019", "Geburtsmonat_2019", "Gender_2019")

###generated data for 2019
data_gen2019 <- data_bjpgen[, c("syear","pid", "labgro19", "emplst19")]
names(data_gen2019) <- c("syear", "pid", "Brutto_imput_2019", "emplstatus_2019")

####merge data via inner join
merge_2018 <- merge(data_2018, data_gen2018, by=("pid"), all.x=F, all.y = F)
merge_2019 <- merge (merge_2018, data_gen2019, by=("pid"), all.x = F, all.y = F)
merge_2019gen <- merge(merge_2019, data_2019, by=("pid"), all.x = F, all.y = F)
names(merge_2019gen)
####missing values
dat_risk_01 <- merge_2019gen[, c("pid",  "sample1_2018", "Geburtsjahr_2018", "Geburtsmonat_2018",
                                 "Gender_2018", "narq_special_2018", "narq_attention_2018", "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018",
                                 "risk_2018", "Schulabschluss_2018", "Bildungsjahre_2018", "isced11_2018",
                                 "Brutto_imput_2018", "Impflag_Netto_2018", "Netto_imput_2018", "emplstatus_2018","Impflag_Brutto_2018","Brutto_imput_2019",
                                 "emplstatus_2019", "Geburtsjahr_2019", "Geburtsmonat_2019", "Gender_2019")]

##minimum value for each variable -> negative values imply missing values
apply(dat_risk_01, 2, function(x) min(x))
dat_risk_backup <- dat_risk_01
dim(dat_risk_01)
##remove all "does not apply (-2)"
dat_bin_risk <- dat_risk_01==-2 #creating a dichotomous data set. If cells have the value -2, they get the value 1, if not, they get the value 0
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk #how many (-2) are there per column
dat_bin_risk_1 <- dat_risk_01==-2
die_behalten_risk_1 <- apply(dat_bin_risk_1, 1, function(x) sum(x))==0 #which rows do not have the value (-2)
dat_risk_notapply <- dat_risk_01[die_behalten_risk_1,] #keep all rows that do not have the value (-2)

dim(dat_risk_notapply)

##remove all "no answer (-1)"
dat_bin_risk <- dat_risk_notapply==-1
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_2 <- dat_risk_notapply==-1
die_behalten_risk_2 <- apply(dat_bin_risk_2, 1, function(x) sum(x))==0
dat_risk_noanswer <- dat_risk_notapply[die_behalten_risk_2,]
dim(dat_risk_noanswer)

##remove all "not included in questionnaire (-5)"
dat_bin_risk <- dat_risk_noanswer==-5
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_3 <- dat_risk_noanswer==-5
die_behalten_risk_3 <- apply(dat_bin_risk_3, 1, function(x) sum(x))==0
dat_risk_notincluded <- dat_risk_noanswer[die_behalten_risk_3,]

dim(dat_risk_notincluded)
apply(dat_risk_notincluded, 2, function(x) min(x))

####create the variable age 2018 from year and month of birth with the lubridate-package
dat_age_risk19 <- dat_risk_notincluded[,c("pid", "Geburtsjahr_2019", "Geburtsmonat_2019")]

geburt_as_char19 <- as.character(dat_age_risk19$Geburtsjahr_2019*10000+dat_age_risk19$Geburtsmonat_2019*100+1)
#change to date-format
geburt_als_date19 <- as.Date(geburt_as_char19, format='%Y%m%d')

# reference date is 15.06.2019 (midpoint of fieldwork period)
referenz_datum19 <- "20190615"    
referenz_datum_as_date19 <- as.Date(referenz_datum19, format='%Y%m%d')
#age in years
dat_age_risk19$age19 <- floor(time_length(difftime(referenz_datum_as_date19, geburt_als_date19), "years")) 
dat_age_risk19 <- dat_age_risk19[,c("pid", "age19")]

####create the variable age 2018 from year and month of birth with the lubridate-package
dat_age_risk18 <- dat_risk_notincluded[,c("pid", "Geburtsjahr_2018", "Geburtsmonat_2018")]

geburt_as_char18 <- as.character(dat_age_risk18$Geburtsjahr_2018*10000+dat_age_risk18$Geburtsmonat_2018*100+1)
#change to date-format
geburt_als_date18 <- as.Date(geburt_as_char18, format='%Y%m%d')

# reference date is 15.06.2018 (midpoint of fieldwork period)
referenz_datum18 <- "20180615"    
referenz_datum_as_date18 <- as.Date(referenz_datum18, format='%Y%m%d')
#age in years
dat_age_risk18$age18 <- floor(time_length(difftime(referenz_datum_as_date18, geburt_als_date18), "years")) 
dat_age_risk18 <- dat_age_risk18[,c("pid", "age18")]


##merging age to dataframe
dat_risk_002 <- merge(dat_risk_notincluded, dat_age_risk18, by=("pid"), all.x=F, all.y = F)
dat_risk_02 <- merge(dat_risk_002, dat_age_risk19, by=("pid"), all.x=F, all.y = F)


#### excluding individuals with income=0 for 2019
dim(dat_risk_02)
dat_risk_02 <- dat_risk_02[dat_risk_02$Brutto_imput_2019!=0,]
dim(dat_risk_02)

sum(dat_risk_02$Brutto_imput_2018==0)
#### excluding individuals with income=0 for 2018
dim(dat_risk_02)
dat_risk_02 <- dat_risk_02[dat_risk_02$Brutto_imput_2018!=0,]
dim(dat_risk_02)


####Outliertreatment for 2019 according to upper outer fence method (NIST/SEMATECH e-Handbook of Statistical Methods)
quant25_income <- as.numeric(quantile(dat_risk_02$Brutto_imput_2019)[2])
quant75_income <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2019)[4])
quant50_income <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2019)[3])
outliervalue_income <- quant75_income+(3*(quant75_income-quant25_income))
dat_risk_02 <-dat_risk_02[(dat_risk_02$Brutto_imput_2019<outliervalue_income),] #excluding all cases that have higher values than 75%-quartile + 3*(75%-quartile - 25%-quartile)
dim(dat_risk_02)
1-11301/11416 #percentage of outliers from 2019 compared to sample with no outlier treatment

####Outliertreatment for 2018 according to upper outer fence method (NIST/SEMATECH e-Handbook of Statistical Methods)
quant25_income18 <- as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[2])
quant75_income18 <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[4])
quant50_income18 <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[3])
outliervalue_income18 <- quant75_income18+(3*(quant75_income18-quant25_income18))
dat_risk_02 <-dat_risk_02[(dat_risk_02$Brutto_imput_2018<outliervalue_income18),] #excluding all cases that have higher values than 75%-quartile + 3*(75%-quartile - 25%-quartile)
dim(dat_risk_02)
1-11253/11416 #percentage of outliers from 2019 compared to sample with no outlier treatment

####logarithm of gross income 2019
hist(dat_risk_02$Brutto_imput_2019, breaks=100)
log_income2019 <- log(dat_risk_02$Brutto_imput_2019) 
hist(log_income2019, breaks=100) 
dat_risk_02$log_income2019 <- log_income2019 

###logarithm of gross income 2018
hist(dat_risk_02$Brutto_imput_2018, breaks=100)
log_income2018 <- log(dat_risk_02$Brutto_imput_2018) 
hist(log_income2018, breaks=100)
dat_risk_02$log_income2018 <- log_income2018 

dat_risk2019 <- dat_risk_02
names(dat_risk2019)

####transfom employmentstatus2018 into a dichotomous variable (0 = part-time, 1 = full-time)
dat_risk2019 <- dat_risk2019[dat_risk2019$emplstatus_2018!=5,]#removing all unemployed (5) individuals from dataframe
dat_risk2019$emplstatus_2018[dat_risk2019$emplstatus_2018>1] <- 0 #recoding all part-time employments (2,3,4,6) to one category, while 1 = full-time employment
table(dat_risk2019$emplstatus_2018)

####transfom employmentstatus2019 into a dichotomous variable (0 = part-time, 1 = full-time)
dat_risk2019 <- dat_risk2019[dat_risk2019$emplstatus_2019!=5,]#removing all unemployed (5) individuals from dataframe
dat_risk2019$emplstatus_2019[dat_risk2019$emplstatus_2019>1] <- 0 #recoding all part-time employments (2,3,4,6) to one category, while 1 = full-time employment
table(dat_risk2019$emplstatus_2019)


####recode Gender 2018 (0 = male, 1 = female)
dat_risk2019$Gender_2018[dat_risk2019$Gender_2018==1] <- 0
dat_risk2019$Gender_2018[dat_risk2019$Gender_2018==2] <- 1

####recode Gender 2019 (0 = male, 1 = female)
dat_risk2019$Gender_2019[dat_risk2019$Gender_2019==1] <- 0
dat_risk2019$Gender_2019[dat_risk2019$Gender_2019==2] <- 1



####aggregated means of rivalry and admiration
dat_risk2019$mean_admiration <- rowMeans(dat_risk2019[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
dat_risk2019$mean_rivalry <- rowMeans(dat_risk2019[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

###Cronbachs alpha of narcissism in the SOEP
#admiration
psych::alpha(dat_risk2019[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
#rivalry
psych::alpha(dat_risk2019[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

####z-standardize independent variables
dat_risk2019$risk_stand <- as.numeric(scale(dat_risk2019$risk_2018, center = T, scale = T))
dat_risk2019$admiration_stand <- as.numeric(scale(dat_risk2019$mean_admiration, center = T, scale = T))
dat_risk2019$rivalry_stand <- as.numeric(scale(dat_risk2019$mean_rivalry, center = T, scale = T))
dat_risk2019$loggrossincome2019_stand <- as.numeric(scale(dat_risk2019$log_income2019, center = T, scale = T))
dat_risk2019$loggrossincome2018_stand <- as.numeric(scale(dat_risk2019$log_income2018, center = T, scale = T))
dat_risk2019$age18_stand <- as.numeric(scale(dat_risk2019$age18, center = T, scale = T))
dat_risk2019$age19_stand <- as.numeric(scale(dat_risk2019$age19, center = T, scale = T))
dat_risk2019$gender18_stand <- as.numeric(scale(dat_risk2019$Gender_2018, center = T, scale = T))
dat_risk2019$gender19_stand <- as.numeric(scale(dat_risk2019$Gender_2019, center = T, scale = T))
dat_risk2019$emplstatus18_stand <- as.numeric(scale(dat_risk2019$emplstatus_2018, center = T, scale = T))
dat_risk2019$emplstatus19_stand <- as.numeric(scale(dat_risk2019$emplstatus_2019, center = T, scale = T))

####center continuous variables for regression analysis
dat_risk2019$age18_zen <- scale(dat_risk2019$age18, center = T, scale = F)
dat_risk2019$age19_zen <- scale(dat_risk2019$age19, center = T, scale = F)

dim(dat_risk2019)

###########################################
##           Exploratory Analyis         ##
###########################################
names(dat_risk2019)
######2018
### linear regression for income 2018 with covariates
# unstandardized
inc18_unst <- lm(log_income2018 ~ mean_admiration+mean_rivalry+age18_zen+Gender_2018+emplstatus_2018+risk_2018,data=dat_risk2019)
summary(inc18_unst)
# standardized
inc18_stand <- lm(log_income2018 ~ admiration_stand+rivalry_stand+age18_stand+gender18_stand+emplstatus18_stand+risk_stand, data=dat_risk2019)
summary(inc18_stand)

### linear regression for income 2018 without covariates
# unstandardized
inc18_unst_nc <- lm(log_income2018 ~ mean_admiration+mean_rivalry+risk_2018,data=dat_risk2019)
summary(inc18_unst_nc)
# standardized
inc18_stand_nc <- lm(log_income2018 ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk2019)
summary(inc18_stand_nc)

## tables report: without covariates, with covariates, standardized, unstandardized
#standardized
stargazer(inc18_stand_nc,inc18_stand, type = "html", 
          title = "Analysis for Income 2018 - Standardized", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income 2018"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table_a_income18_standardized.html")
#unstandardized
stargazer(inc18_unst_nc,inc18_unst, type = "html", 
          title = "Analysis for Income 2018 - Unstandardized", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income 2018"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table_b_income18_unstandardized.html")

######2019
### linear regression for income 2019 with covariates
# unstandardized
inc19_unst <- lm(log_income2019 ~ mean_admiration+mean_rivalry+age18_zen+Gender_2018+emplstatus_2018+risk_2018,data=dat_risk2019)
summary(inc19_unst)
# standardized
inc19_stand <- lm(log_income2019 ~ admiration_stand+rivalry_stand+age18_stand+gender18_stand+emplstatus18_stand+risk_stand, data=dat_risk2019)
summary(inc19_stand)

### linear regression for income 2019 without covariates
# unstandardized
inc19_unst_nc <- lm(log_income2019 ~ mean_admiration+mean_rivalry+risk_2018,data=dat_risk2019)
summary(inc19_unst_nc)
# standardized
inc19_stand_nc <- lm(log_income2019 ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk2019)
summary(inc19_stand_nc)

## tables report: without covariates, with covariates, standardized, unstandardized
#standardized
stargazer(inc19_stand_nc,inc19_stand, type = "html", 
          title = "Analysis for Income 2019 - Standardized", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income 2019"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table_c_income19_standardized.html")
#unstandardized
stargazer(inc19_unst_nc,inc19_unst, type = "html", 
          title = "Analysis for Income 2019 - Unstandardized", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income 2019"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table_d_income19_unstandardized.html")

names(dat_risk2019)
