###########################################
##           Data preparation            ##
###########################################
Daten <- "P:/Syntax"
setwd(Daten)


####load required packages
library(psych)
library(sjPlot)
library(weights)
library(haven)
library(lubridate)
library(Weighted.Desc.Stat)
library(MASS)
library(mediation)
library(stargazer)
library(ggplot2)
library(tidyverse)
library(survey)
library(RSA)
####read original SOEP data
###individual data set for 2018
#path_bip <- file.choose() # only the first time in your respective folder
path_bip <- "../Daten/SPSS_DE/raw/bip.sav" # important: you must have the working directory in a subfolder or a project 
data_bip <- data.frame(read_sav(path_bip))
###generated data for 2018
#path_bipgen <- file.choose()
path_bipgen <- "../Daten/SPSS_DE/raw/bipgen.sav"
data_bipgen <- data.frame(read_sav(path_bipgen))
###weights
#path_phrf <- file.choose()
path_phrf <- "../Daten/SPSS_DE/raw/phrf.sav"
data_phrf <- data.frame(read_sav(path_phrf))

####ensuring that each person is only existing once in the dataframe
max(table(data_bip$pid))
max(table(data_bipgen$pid))

####select and rename variables
###individual data set for 2018
data_2018 <- data_bip[, c("pid", "sample1", "bipnr",
                          "bipbirthy", "bipbirthm", "sex", "bip_09_01", "bip_09_02",
                          "bip_09_03", "bip_09_04", "bip_09_05", "bip_09_06", "bip_14", "bip_15", "bip_16", "bip_29_02",
                          "bip_43", "bip_97_01", "bip_97_02", "bip_108", "bip_117_01", "bip_117_02", "bip_117_03","bip_191",
                          "bip_202_01")]

names(data_2018) <- c("pid", "sample1_2018", "bipnr",
                      "Geburtsjahr_2018", "Geburtsmonat_2018", "Gender_2018",  "narq_special_2018", "narq_attention_2018",
                      "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018", "impatient_2018", "risk_2018", "impusive_2018", "education_2018",
                      "employ_status_2018", "grossincome_2018", "netincome_2018", "sidejob_2018", "grossincome_sj1_2018", "grossincome_sj2_2018", "grossincome_sj3_2018","marital_status_2018",
                      "life_satisfaction_2018")

###generated data for 2018
data_gen2018 <- data_bipgen[, c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nation18", "bipsbil", "bipbbil01", "bipbbil02", "bibilzeit", 
                                "isced11_18", "labgro18", "impnet18", "kldb2010_18", "labnet18", "emplst18", "impgro18")]

names(data_gen2018) <- c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nationalitaet_2018", "Schulabschluss_2018", "berufl_Bildung_2018", "Hochschulabschluss_2018", "Bildungsjahre_2018", 
                         "isced11_2018", "Brutto_imput_2018", "Impflag_Netto_2018", "kldb2010_2018", "Netto_imput_2018", "emplstatus_2018", "Impflag_Brutto_2018")

####merge data via inner join
merge_2018 <- merge(data_2018, data_gen2018, by=("pid"), all.x=F, all.y = F)
merge_weights <- merge(merge_2018, data_phrf, by=("pid"), all.x=F, all.y = F)

####missing values
dat_risk_01 <- merge_weights[, c("pid",  "sample1_2018", "Geburtsjahr_2018", "Geburtsmonat_2018",
                                   "Gender_2018", "narq_special_2018", "narq_attention_2018", "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018",
                                    "risk_2018", "Schulabschluss_2018", "Bildungsjahre_2018", "isced11_2018",
                                   "Brutto_imput_2018", "Impflag_Netto_2018", "Netto_imput_2018", "emplstatus_2018","Impflag_Brutto_2018","biphrf")]

##minimum value for each variable -> negative values imply missing values
apply(dat_risk_01, 2, function(x) min(x))
dat_risk_backup <- dat_risk_01
dim(dat_risk_01)
##remove all "does not apply (-2)"
dat_bin_risk <- dat_risk_01==-2 #creating a dichotomous data set. If cells have the value -2, they get the value 1, if not, they get the value 0
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk #how many (-2) are there per column
dat_bin_risk_1 <- dat_risk_01==-2
die_behalten_risk_1 <- apply(dat_bin_risk_1, 1, function(x) sum(x))==0 #which rows do not have the value (-2)
dat_risk_notapply <- dat_risk_01[die_behalten_risk_1,] #keep all rows that do not have the value (-2)

dim(dat_risk_notapply)

##remove all "no answer (-1)"
dat_bin_risk <- dat_risk_notapply==-1
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_2 <- dat_risk_notapply==-1
die_behalten_risk_2 <- apply(dat_bin_risk_2, 1, function(x) sum(x))==0
dat_risk_noanswer <- dat_risk_notapply[die_behalten_risk_2,]

dim(dat_risk_noanswer)

##remove all "not included in questionnaire (-5)"
dat_bin_risk <- dat_risk_noanswer==-5
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_3 <- dat_risk_noanswer==-5
die_behalten_risk_3 <- apply(dat_bin_risk_3, 1, function(x) sum(x))==0
dat_risk_notincluded <- dat_risk_noanswer[die_behalten_risk_3,]

dim(dat_risk_notincluded)
apply(dat_risk_notincluded, 2, function(x) min(x))

####create the variable age from year and month of birth with the lubridate-package
dat_age_risk <- dat_risk_notincluded[,c("pid", "Geburtsjahr_2018", "Geburtsmonat_2018")]

geburt_as_char <- as.character(dat_age_risk$Geburtsjahr_2018*10000+dat_age_risk$Geburtsmonat_2018*100+1)
#change to date-format
geburt_als_date <- as.Date(geburt_as_char, format='%Y%m%d')
# reference date is 15.06.2018 (midpoint of fieldwork period)
referenz_datum <- "20180615"    
referenz_datum_as_date <- as.Date(referenz_datum, format='%Y%m%d')
#age in years
dat_age_risk$alter <- floor(time_length(difftime(referenz_datum_as_date, geburt_als_date), "years")) 
dat_age_risk <- dat_age_risk[,c("pid", "alter")]
##merging age to dataframe
dat_risk_02 <- merge(dat_risk_notincluded, dat_age_risk, by=("pid"), all.x=F, all.y = F)

#### excluding individuals with income=0
dat_risk_02 <- dat_risk_02[dat_risk_02$Brutto_imput_2018!=0,]
dim(dat_risk_02)


####Outliertreatment according to upper outer fence method (NIST/SEMATECH e-Handbook of Statistical Methods)
quant25_income <- as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[2])
quant75_income <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[4])
quant50_income <-  as.numeric(quantile(dat_risk_02$Brutto_imput_2018)[3])
outliervalue_income <- quant75_income+(3*(quant75_income-quant25_income))
dat_risk_02 <-dat_risk_02[(dat_risk_02$Brutto_imput_2018<outliervalue_income),] #excluding all cases that have higher values than 75%-quartile + 3*(75%-quartile - 25%-quartile)
dim(dat_risk_02)
1-14527/14749 #percentage of outliers

####logarithm of gross income
hist(dat_risk_02$Brutto_imput_2018, breaks=100)
log_income <- log(dat_risk_02$Brutto_imput_2018) 
?log
hist(log_income, breaks=100) 
dat_risk_02$log_income <- log_income  
dat_risk <- dat_risk_02

####transfom employmentstatus into a dichotomous variable (0 = part-time, 1 = full-time)
dat_risk <- dat_risk[dat_risk$emplstatus_2018!=5,]#removing all unemployed (5) individuals from dataframe
dat_risk$emplstatus_2018[dat_risk$emplstatus_2018>1] <- 0 #recoding all part-time employments (2,3,4,6) to one category, while 1 = full-time employment
table(dat_risk$emplstatus_2018)

####recode Gender (0 = male, 1 = female)
dat_risk$Gender_2018[dat_risk$Gender_2018==1] <- 0
dat_risk$Gender_2018[dat_risk$Gender_2018==2] <- 1

####aggregated means of rivalry and admiration
dat_risk$mean_admiration <- rowMeans(dat_risk[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
dat_risk$mean_rivalry <- rowMeans(dat_risk[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

###Cronbachs alpha of narcissism in the SOEP
#admiration
psych::alpha(dat_risk[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
#rivalry
psych::alpha(dat_risk[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

####z-standardize independent variables
dat_risk$risk_stand <- as.numeric(scale(dat_risk$risk_2018, center = T, scale = T))
dat_risk$admiration_stand <- as.numeric(scale(dat_risk$mean_admiration, center = T, scale = T))
dat_risk$rivalry_stand <- as.numeric(scale(dat_risk$mean_rivalry, center = T, scale = T))
dat_risk$loggrossincome_stand <- as.numeric(scale(dat_risk$log_income, center = T, scale = T))
dat_risk$age_stand <- as.numeric(scale(dat_risk$alter, center = T, scale = T))
dat_risk$gender_stand <- as.numeric(scale(dat_risk$Gender_2018, center = T, scale = T))

dat_risk$emplstatus_stand <- as.numeric(scale(dat_risk$emplstatus_2018, center = T, scale = T))

####center continuous variables for regression analysis
dat_risk$alter_zen <- scale(dat_risk$alter, center = T, scale = F)
dat_risk$loggrossincome_zen <- scale(dat_risk$log_income, center = T, scale = F)

###########################################
##           Main analyses               ##
###########################################

####descriptive statistics: weighted means and standard deviations
num_cols <- c("Brutto_imput_2018","risk_2018","mean_admiration", "mean_rivalry","emplstatus_2018","Gender_2018", "alter","log_income")
apply(dat_risk[,num_cols],2, function(x) w.mean(x, dat_risk$biphrf))
apply(dat_risk[,num_cols],2, function(x)w.sd(x, dat_risk$biphrf))

#weighted tables for gender and employment status
#weighted table for gender
wtd.table(x=dat_risk$Gender_2018, weights=dat_risk$biphrf)$sum.of.weights/sum(dat_risk$biphrf) #ratios
wtd.table(x=dat_risk$Gender_2018, weights=dat_risk$biphrf)$sum.of.weights/sum(dat_risk$biphrf)*nrow(dat_risk) #absolut

###Weighted correlations and p-values
weighted_cors <- wtd.cor(dat_risk[,num_cols], weight=dat_risk$biphrf)
round(weighted_cors$correlation,3)
round(weighted_cors$p.value,3)

#### Regressions
###ordered-probit for risk-taking with covariates
dat_risk$risk_2018_fac <- as.factor(dat_risk$risk_2018)
class(dat_risk$risk_2018_fac)
# unstandardized + not weighted
risk_unst_notw <- polr(risk_2018_fac ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018,data=dat_risk, method = "probit", Hess = T)
summary(risk_unst_notw)

# unstandardized + weighted
risk_unst_w <- polr(risk_2018_fac ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018, data=dat_risk, weights=dat_risk$biphrf, method = "probit", Hess = T)
summary(risk_unst_w)

# standardized + not weighted
risk_stand_notw <- polr(risk_2018_fac ~ admiration_stand+rivalry_stand+age_stand+gender_stand, data=dat_risk, method = "probit", Hess = T)
summary(risk_stand_notw)

# standardized + weighted
risk_stand_w <- polr(risk_2018_fac ~ admiration_stand+rivalry_stand+age_stand+gender_stand, data=dat_risk, weights=dat_risk$biphrf, method = "probit", Hess = T)
summary(risk_stand_w)

###ordered-probit for risk-taking without covariates

# unstandardized + not weighted
risk_unst_notw_nc <- polr(risk_2018_fac ~ mean_admiration+mean_rivalry,data=dat_risk, method = "probit", Hess = T)
summary(risk_unst_notw_nc)

# unstandardized + weighted
risk_unst_w_nc <- polr(risk_2018_fac ~ mean_admiration+mean_rivalry, data=dat_risk, weights=dat_risk$biphrf, method = "probit", Hess = T)
summary(risk_unst_w_nc)

# standardized + not weighted
risk_stand_notw_nc <- polr(risk_2018_fac ~ admiration_stand+rivalry_stand, data=dat_risk, method = "probit", Hess = T)
summary(risk_stand_notw_nc)

# standardized + weighted
risk_stand_w_nc <- polr(risk_2018_fac ~ admiration_stand+rivalry_stand, data=dat_risk, weights=dat_risk$biphrf, method = "probit", Hess = T)
summary(risk_stand_w_nc)

## tables report: without covariates, with covariates, standardized, unstandardized,weighted,unweighted
# with weights
#standardized
stargazer(risk_stand_w_nc,risk_stand_w, type = "html", 
          title = "Standardized - with weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_weights_standardized.html")
#unstandardized
stargazer(risk_unst_w_nc,risk_unst_w, type = "html", 
          title = "Unstandardized - with weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_weights_unstandardized.html")

# no weights
#standardized
stargazer(risk_stand_notw_nc,risk_stand_notw, type = "html", 
          title = "Standardized - without weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_No_weights_standardized.html")

#unstandardized
stargazer(risk_unst_notw_nc,risk_unst_notw, type = "html", 
          title = "Unstandardized - without weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_No_weights_unstandardized.html")

### linear regression for income with covariates

# unstandardized + not weighted
inc_unst_notw <- lm(log_income ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018+emplstatus_2018+risk_2018,data=dat_risk)
summary(inc_unst_notw)

# unstandardized + weighted
inc_unst_w <- lm(log_income ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018+emplstatus_2018+risk_2018, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_unst_w)

# standardized + not weighted
inc_stand_notw <- lm(log_income ~ admiration_stand+rivalry_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk)
summary(inc_stand_notw)

# standardized + weighted
inc_stand_w <- lm(log_income ~ admiration_stand+rivalry_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_stand_w)

### linear regression for income without covariates
# unstandardized + not weighted
inc_unst_notw_nc <- lm(log_income ~ mean_admiration+mean_rivalry+risk_2018,data=dat_risk)
summary(inc_unst_notw_nc)

# unstandardized + weighted
inc_unst_w_nc <- lm(log_income ~ mean_admiration+mean_rivalry+risk_2018, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_unst_w_nc)

# standardized + not weighted
inc_stand_notw_nc <- lm(log_income ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk)
summary(inc_stand_notw_nc)

# standardized + weighted
inc_stand_w_nc <- lm(log_income ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_stand_w_nc)

## tables report: without covariates, with covariates, standardized, unstandardized,weighted,unweighted
#weights
#standardized
stargazer(inc_stand_w_nc,inc_stand_w, type = "html", 
          title = "Standardized - with weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_weights_standardized.html")
#unstandardized
stargazer(inc_unst_w_nc,inc_unst_w, type = "html", 
          title = "Unstandardized - with weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_weights_unstandardized.html")

#without weights
#standardized
stargazer(inc_stand_notw_nc,inc_stand_notw, type = "html", 
          title = "Standardized - without weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_No_weights_standardized.html")
#unstandardized
stargazer(inc_unst_notw_nc,inc_unst_notw, type = "html", 
          title = "Unstandardized - without weights", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_No_weights_unstandardized.html")


##############################################################################
####Exploratory analyses: supression effects
##############################################################################
dim(dat_risk)
names(dat_risk)

#distributions for admiration and rivalry
hist(dat_risk$mean_admiration)
hist(dat_risk$mean_rivalry)

#bivariate scatterplot
p <- ggplot(dat_risk, mapping = aes(x = mean_admiration, y = mean_rivalry))

mytheme <- theme_bw() + theme(aspect.ratio = 1)
mylabels <- labs(x = "admiration", y = "rivalry")

p + 
  geom_jitter() +  # using geom_jitter to avoid overplotting of points
  geom_smooth() +
  mylabels  +
  mytheme


#correlation
cor.test(dat_risk$mean_admiration, dat_risk$mean_rivalry)

cor.test(dat_risk$mean_admiration, dat_risk$risk_2018)
cor.test(dat_risk$mean_rivalry, dat_risk$risk_2018)

cor.test(dat_risk$mean_admiration, dat_risk$log_income)
cor.test(dat_risk$mean_rivalry, dat_risk$log_income)

#mean of admiration and rivalry
dat_risk$mean_a_r <- rowMeans(dat_risk[,c( "mean_admiration", "mean_rivalry")])
#differencescore admiration - rivalry
dat_risk$diff_a_r <- dat_risk$mean_admiration - dat_risk$mean_rivalry

#z-standardize mean_a_r and diff_a_r
dat_risk$mean_a_r_stand <- as.numeric(scale(dat_risk$mean_a_r, center = T, scale = T))
dat_risk$diff_a_r_stand <- as.numeric(scale(dat_risk$diff_a_r, center = T, scale = T))

#####Regressions for risk and income with adm and riv and with mean and diff
###Risk
#multiple regression with standardized admiration and rivalry on risk
risk_stand_notw_nc <- polr(risk_2018_fac ~ admiration_stand+rivalry_stand + age_stand + gender_stand, data=dat_risk, method = "probit", Hess = T)
summary(risk_stand_notw_nc)

#multiple regression with standardized mean_a_r and diff_a_r on risk
surpressor_risk_stand <- polr(risk_2018_fac ~ mean_a_r_stand+diff_a_r_stand + age_stand + gender_stand, data=dat_risk, method = "probit", Hess = T)
summary(surpressor_risk_stand)

stargazer(surpressor_risk_stand, type = "html", 
          title = "Standardized Regression on Risk Attitude: Level and Difference Approach", 
          digits = 2, ci=T, 
          dep.var.labels = c("Risk-attitude"), 
          covariate.labels = c("Mean-Score (adm + riv)", "Difference-Score (adm - riv)","age", "female"),
          out = "Tables/table5_Standardized_Level_and_Difference_Approach_on_Risk.html")

#####Plots for standardized Mean- and Differencescores on Risk
mytheme <- theme_bw() + theme(aspect.ratio = 1)
mylabels_mean <- labs(y = "Mean-Score (Admiration + Rivalry)", x = "Risk-Attitude")
mylabels_diff <- labs(y = "Difference-Score (Admiration - Rivalry)", x = "Risk-Attitude")

#Plot for standardized Admiration + rivalry
ggplot(dat_risk,aes(y = mean_a_r_stand, x = risk_2018_fac)) + 
  geom_boxplot(alpha = .2) +
  mytheme+
  mylabels_mean

ggsave("../Figs/Boxplot_Risk_On_Stand_Mean_Adm_Riv.jpg",dpi = 600, unit = "cm" , height = 10, width = 10)


#Plot for standardized Admiration - rivalry
ggplot(dat_risk,aes(y = diff_a_r_stand, x = risk_2018_fac)) + 
  geom_boxplot(alpha = .2) +
  mytheme+
  mylabels_diff
ggsave("../Figs/Boxplot_Risk_On_Stand_Diff_Adm_Riv.jpg",dpi = 600, unit = "cm" , height = 10, width = 10)


##########Income
#multiple regression with standardized admiration and rivalry on income
inc_stand_notw <- lm(log_income ~ admiration_stand+rivalry_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk)
summary(inc_stand_notw)

#multiple regression with standardized mean_a_r and diff_a_r on income
suppressor_income_stand <- lm(log_income ~ mean_a_r_stand+diff_a_r_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk)
summary(suppressor_income_stand)
#Table for standardized regression of Mean-and Difference-Scores on Income
stargazer(suppressor_income_stand, type = "html", 
          title = "Standardized Regression on Income: Level and Difference Approach", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("Mean-Score (adm + riv)", "Difference-Score (adm - riv)","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table4_Standardized_Level_and_Difference_Approach_on_income.html")

#####Plots for standardized Mean- and Differencescores on Income
mytheme <- theme_bw() + theme(aspect.ratio = 1)
mylabels_mean <- labs(x = "Mean-Score (Admiration + Rivalry)", y = "Log-Income")
mylabels_diff <- labs(x = "Difference-Score (Admiration - Rivalry)", y = "Log-Income")

#Plot for standardized Admiration + rivalry on Income
ggplot(dat_risk,aes(x = mean_a_r_stand, y = log_income)) + 
  geom_point(alpha = .2) +
  geom_line(data = dat_risk, aes(y = -0.02*mean_a_r_stand + 7.61))+
  mytheme+
  mylabels_mean
ggsave("../Figs/Scatterplot_Income_on_Stand_Mean_Adm_Riv.jpg",dpi = 600, unit = "cm" , height = 10, width = 10)

#Plot for standardized Admiration - rivalry
ggplot(dat_risk,aes(x = diff_a_r_stand, y = log_income)) + 
  geom_point(alpha = .2) +
  geom_line(data = dat_risk, aes(y = 0.04*diff_a_r_stand + 7.61))+
  mytheme+
  mylabels_diff
ggsave("../Figs/Scatterplot_Income_On_Stand_Diff_Adm_Riv.jpg",dpi = 600, unit = "cm" , height = 10, width = 10)

#clear your workspace!!
ls()
rm()
rm(list=setdiff(ls(), "dat_risk"))

#########################################################
#########Plot for income at -/+ 1 SD and mean admiration#
#########################################################
# SD of admiration
sd_adm <- sd(dat_risk$mean_admiration)
#get the value of admirations regression coefficient
b_admiration <- inc_unst_w$coefficients["mean_admiration"]

# mean log income +/- B(admiration)*SD(admiration)
mean_eink_log
mean_eink_log_plus_sd_adm <- mean_eink_log+b_admiration*sd_adm
mean_eink_log_minus_sd_adm <- mean_eink_log-b_admiration*sd_adm

#retransform the log to natural values
mean_eink_unlog
mean_eink_unlog_plus_sd_adm <- as.numeric(exp(mean_eink_log_plus_sd_adm))
mean_eink_unlog_minus_sd_adm<- as.numeric(exp(mean_eink_log_minus_sd_adm))

mean_eink_unlog_plus_sd_adm
mean_eink_unlog
mean_eink_unlog_minus_sd_adm

#build a dataframe with the predicted values for plotting
dat_admiration <- data.frame("Admiration"=c(1,2,3),
                             "Income"=c(mean_eink_unlog_minus_sd_adm,mean_eink_unlog,mean_eink_unlog_plus_sd_adm))
library(ggplot2)
ggplot(data=dat_admiration, aes(x=Admiration, y=Income, group=1)) +
  geom_line()+
  geom_point(color="red")+
  scale_x_continuous(name = "Admiration",breaks=c(1,2,3), labels = c("-1 SD", "Mean", "+1 SD")) +
  theme_bw()


######################################################
#########Plot for income at -/+ 1 SD and mean rivalry#
######################################################
# SD of rivalry
sd_riv <- sd(dat_risk$mean_rivalry)
#get the value of rivalrys regression coefficient
b_rivalry <- inc_unst_w$coefficients["mean_rivalry"]

# mean log income +/- B(rivalry)*SD(rivalry)
mean_eink_log
mean_eink_log_plus_sd_riv <- mean_eink_log+b_rivalry*sd_riv
mean_eink_log_minus_sd_riv <- mean_eink_log-b_rivalry*sd_riv

#retransform the log to natural values
mean_eink_unlog
mean_eink_unlog_plus_sd_riv <- as.numeric(exp(mean_eink_log_plus_sd_riv))
mean_eink_unlog_minus_sd_riv<- as.numeric(exp(mean_eink_log_minus_sd_riv))

mean_eink_unlog_plus_sd_riv
mean_eink_unlog
mean_eink_unlog_minus_sd_riv

#build a dataframe with the predicted values for plotting
dat_rivalry <- data.frame("Rivalry"=c(1,2,3),
                          "Income"=c(mean_eink_unlog_minus_sd_riv,mean_eink_unlog,mean_eink_unlog_plus_sd_riv))
library(ggplot2)
ggplot(data=dat_rivalry, aes(x=Rivalry, y=Income, group=1)) +
  geom_line()+
  geom_point(color="red")+
  scale_x_continuous(name = "Rivalry",breaks=c(1,2,3), labels = c("-1 SD", "Mean", "+1 SD")) +
  theme_bw()


##############################################################################
####Exploratory analyses: Polynomial Regression and RSA                     ##
##############################################################################
dim(dat_risk)
names(dat_risk)
#center the predictors
dat_risk$admiration_zen <- as.numeric(scale(dat_risk$mean_admiration, center = T, scale = F))
dat_risk$rivalry_zen <- as.numeric(scale(dat_risk$mean_rivalry, center = T, scale = F))
#product term
dat_risk$adm_riv_product <- dat_risk$admiration_zen*dat_risk$rivalry_zen
#quadratic terms
dat_risk$quadmiration_zen <- dat_risk$admiration_zen^2
dat_risk$qurivalry_zen <- dat_risk$rivalry_zen^2

#run polynomial regression
#for risk
risk_poly <- polr(risk_2018_fac ~ admiration_zen+rivalry_zen+quadmiration_zen+adm_riv_product+qurivalry_zen, data=dat_risk, weights=dat_risk$biphrf, method = "probit", Hess = T)
summary(risk_poly)
risk_poly$edf
#table for polynomial regression on risk
stargazer(risk_poly, type = "html", 
          title = "Weighted Polynomial Regression Analysis for Admiration and Rivalry on Risk Attitude", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration (b1)", "rivalry(b2)", "Curvilinear admiration (b3)", "Product adm*riv (b4)", "Curvilinear rivalry (b5)"),
          out = "Tables/table_s12_polynom_risk_attitude.html")
#for income
income_poly <- lm(log_income ~ admiration_zen+rivalry_zen+quadmiration_zen+adm_riv_product+qurivalry_zen, data=dat_risk, weights=dat_risk$biphrf)
summary(income_poly)

#table for polynomial regression on income
stargazer(income_poly, type = "html", 
          title = "Weighted Polynomial Regression Analysis for Admiration and Rivalry on Income", 
          digits = 2, ci=T, 
          dep.var.labels = c("log-income"), 
          covariate.labels = c("admiration (b1)", "rivalry(b2)", "Curvilinear admiration (b3)", "Product adm*riv (b4)", "Curvilinear rivalry (b5)"),
          out = "Tables/table_s13_polynom_income.html")


#RSA for Risk
win.metafile('rsa_plot_risk2.wmf')
points_data_risk <-  dat_risk[,c("admiration_zen","rivalry_zen","risk_2018_fac")]
summary(points_data_risk)
points_data_risk
points_data_risk$risk_2018_fac <- as.numeric(points_data_risk$risk_2018_fac)
plotRSA(y = 0.047, x = 0.147, xy = -0.021, y2 = -0.021, x2 = 0.011, type = "3d", model = "full"
         ,points=list(data=points_data_risk,value="predicted"), hull=T
         ,ylab = "Rivalry", xlab = "Admiration", zlab = "Risk Attitude", axes = c("LOC", "LOIC", "PA1", "PA2"),param = T, zlim = c(-1, 1),
         axesStyles = list(LOC = list(lty = "solid", lwd = 2, col = "blue")
                           , LOIC = list(lty = "solid", lwd = 2, col = "red"), PA1 = list(lty = "solid", lwd = 2
                                     , col = "black"), PA2 = list(lty = "solid", lwd = 2,col = "gray30")))
dev.off()

#test the significance of a1-a5
mymodel_risk <- summary(risk_poly)
RSA_RISK <- RSA.ST(x = mymodel_risk$coefficients[1,1],
       y = mymodel_risk$coefficients[2,1],
       x2 = mymodel_risk$coefficients[3,1],
       xy = mymodel_risk$coefficients[4,1],
       y2 = mymodel_risk$coefficients[5,1], 
       SE=c(x = mymodel_risk$coefficients[1,2],
            y = mymodel_risk$coefficients[2,2],
            x2 = mymodel_risk$coefficients[3,2],
            xy = mymodel_risk$coefficients[4,2],
            y2 = mymodel_risk$coefficients[5,2]),
       COV=c(x_y=vcov(risk_poly)[1,2],
             x2_y2 = vcov(risk_poly)[3,5],
             x2_xy = vcov(risk_poly)[3,4],
             y2_xy = vcov(risk_poly)[5,4])
       , df= risk_poly$edf)

#CI
RSA_RISK$SP["upper_CI"] <-RSA_RISK$SP$estimate+RSA_RISK$SP$SE*1.96
RSA_RISK$SP["lower_CI"] <-RSA_RISK$SP$estimate-RSA_RISK$SP$SE*1.96
RSA_RISK


#RSA for Income
win.metafile('rsa_plot_income.wmf')
points_data_income <-  dat_risk[,c("admiration_zen","rivalry_zen","log_income")]
plotRSA(y = 0.0492, x = 0.0216, xy = -0.007, y2 = -0.049, x2 = -0.017, type = "3d", model = "full"
        ,points=list(data=points_data_income,value="predicted"), hull=T
        ,ylab = "Rivalry", xlab = "Admiration", zlab = "Log Income", axes = c("LOC", "LOIC", "PA1", "PA2"),param = T, zlim = c(-1, 1),
         axesStyles = list(LOC = list(lty = "solid", lwd = 2, col = "blue")
                           , LOIC = list(lty = "solid", lwd = 2, col = "red"), PA1 = list(lty = "solid", lwd = 2
                                         , col = "black"), PA2 = list(lty = "solid", lwd = 2,col = "gray30")))
dev.off()
#test the significance of a1-a5
vcov(income_poly) #covariance matrix for significance testing
mymodel <- summary(income_poly)
RSA_INCOME <- RSA.ST(x = mymodel$coefficients[2,1],
       y = mymodel$coefficients[3,1],
       x2 = mymodel$coefficients[4,1],
       xy = mymodel$coefficients[5,1],
       y2 = mymodel$coefficients[6,1], 
       SE=c(x = mymodel$coefficients[2,2],
            y = mymodel$coefficients[3,2],
            x2 = mymodel$coefficients[4,2],
            xy = mymodel$coefficients[5,2],
            y2 = mymodel$coefficients[6,2]),
       COV=c(x_y=vcov(income_poly)[3,2],
             x2_y2 = vcov(income_poly)[6,4],
             x2_xy = vcov(income_poly)[5,4],
             y2_xy = vcov(income_poly)[6,5])
       , df= mymodel$df[2])


RSA_INCOME$SP["upper_CI"] <-RSA_INCOME$SP$estimate+RSA_INCOME$SP$SE*1.96
RSA_INCOME$SP["lower_CI"] <-RSA_INCOME$SP$estimate-RSA_INCOME$SP$SE*1.96
RSA_INCOME
