#################################################################
##           Data preparation without outlier treatment        ##
#################################################################
Daten <- "P:/Syntax"
setwd(Daten)

####load required packages
library(psych)
library(sjPlot)
library(weights)
library(haven)
library(lubridate)
library(Weighted.Desc.Stat)
library(MASS)
library(mediation)
library(stargazer)
library(ggplot2)
library(tidyverse)
library(survey)
####read original SOEP data
###individual data set for 2018
#path_bip <- file.choose() # only the first time in your respective folder
path_bip <- "../Daten/SPSS_DE/raw/bip.sav" # important: you must have the working directory in a subfolder or a project 
data_bip <- data.frame(read_sav(path_bip))
###generated data for 2018
#path_bipgen <- file.choose()
path_bipgen <- "../Daten/SPSS_DE/raw/bipgen.sav"
data_bipgen <- data.frame(read_sav(path_bipgen))
###weights
#path_phrf <- file.choose()
path_phrf <- "../Daten/SPSS_DE/raw/phrf.sav"
data_phrf <- data.frame(read_sav(path_phrf))

####ensuring that each person is only existing once in the dataframe
max(table(data_bip$pid))
max(table(data_bipgen$pid))

####select and rename variables
###individual data set for 2018
data_2018 <- data_bip[, c("pid", "sample1", "bipnr",
                          "bipbirthy", "bipbirthm", "sex", "bip_09_01", "bip_09_02",
                          "bip_09_03", "bip_09_04", "bip_09_05", "bip_09_06", "bip_14", "bip_15", "bip_16", "bip_29_02",
                          "bip_43", "bip_97_01", "bip_97_02", "bip_108", "bip_117_01", "bip_117_02", "bip_117_03","bip_191",
                          "bip_202_01")]

names(data_2018) <- c("pid", "sample1_2018", "bipnr",
                      "Geburtsjahr_2018", "Geburtsmonat_2018", "Gender_2018",  "narq_special_2018", "narq_attention_2018",
                      "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018", "impatient_2018", "risk_2018", "impusive_2018", "education_2018",
                      "employ_status_2018", "grossincome_2018", "netincome_2018", "sidejob_2018", "grossincome_sj1_2018", "grossincome_sj2_2018", "grossincome_sj3_2018","marital_status_2018",
                      "life_satisfaction_2018")

###generated data for 2018
data_gen2018 <- data_bipgen[, c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nation18", "bipsbil", "bipbbil01", "bipbbil02", "bibilzeit", 
                                "isced11_18", "labgro18", "impnet18", "kldb2010_18", "labnet18", "emplst18", "impgro18")]

names(data_gen2018) <- c("cid", "hid", "pid","syear", "hhnr", "bihhnr", "hhnrakt", "persnr", "nationalit?t_2018", "Schulabschluss_2018", "berufl_Bildung_2018", "Hochschulabschluss_2018", "Bildungsjahre_2018", 
                         "isced11_2018", "Brutto_imput_2018", "Impflag_Netto_2018", "kldb2010_2018", "Netto_imput_2018", "emplstatus_2018", "Impflag_Brutto_2018")

####merge data via inner join
merge_2018 <- merge(data_2018, data_gen2018, by=("pid"), all.x=F, all.y = F)
merge_weights <- merge(merge_2018, data_phrf, by=("pid"), all.x=F, all.y = F)

####missing values
dat_risk_01 <- merge_weights[, c("pid",  "sample1_2018", "Geburtsjahr_2018", "Geburtsmonat_2018",
                                 "Gender_2018", "narq_special_2018", "narq_attention_2018", "narq_annoyed_2018", "narq_personality_2018", "narq_rivals_2018", "narq_losers_2018",
                                 "risk_2018", "Schulabschluss_2018", "Bildungsjahre_2018", "isced11_2018",
                                 "Brutto_imput_2018", "Impflag_Netto_2018", "Netto_imput_2018", "emplstatus_2018","Impflag_Brutto_2018","biphrf")]

##minimum value for each variable -> negative values imply missing values
apply(dat_risk_01, 2, function(x) min(x))
dat_risk_backup <- dat_risk_01
dim(dat_risk_01)
##remove all "does not apply (-2)"
dat_bin_risk <- dat_risk_01==-2 #creating a dichotomous data set. If cells have the value -2, they get the value 1, if not, they get the value 0
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk #how many (-2) are there per column
dat_bin_risk_1 <- dat_risk_01==-2
die_behalten_risk_1 <- apply(dat_bin_risk_1, 1, function(x) sum(x))==0 #which rows do not have the value (-2)
dat_risk_notapply <- dat_risk_01[die_behalten_risk_1,] #keep all rows that do not have the value (-2)

dim(dat_risk_notapply)

##remove all "no answer (-1)"
dat_bin_risk <- dat_risk_notapply==-1
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_2 <- dat_risk_notapply==-1
die_behalten_risk_2 <- apply(dat_bin_risk_2, 1, function(x) sum(x))==0
dat_risk_noanswer <- dat_risk_notapply[die_behalten_risk_2,]

dim(dat_risk_noanswer)

##remove all "not included in questionnaire (-5)"
dat_bin_risk <- dat_risk_noanswer==-5
die_behalten_risk <- apply(dat_bin_risk, 2, function(x) sum(x)); die_behalten_risk
dat_bin_risk_3 <- dat_risk_noanswer==-5
die_behalten_risk_3 <- apply(dat_bin_risk_3, 1, function(x) sum(x))==0
dat_risk_notincluded <- dat_risk_noanswer[die_behalten_risk_3,]

dim(dat_risk_notincluded)
apply(dat_risk_notincluded, 2, function(x) min(x))

####create the variable age from year and month of birth with the lubridate-package
dat_age_risk <- dat_risk_notincluded[,c("pid", "Geburtsjahr_2018", "Geburtsmonat_2018")]

geburt_as_char <- as.character(dat_age_risk$Geburtsjahr_2018*10000+dat_age_risk$Geburtsmonat_2018*100+1)
#change to date-format
geburt_als_date <- as.Date(geburt_as_char, format='%Y%m%d')
# reference date is 15.06.2018 (midpoint of fieldwork period)
referenz_datum <- "20180615"    
referenz_datum_as_date <- as.Date(referenz_datum, format='%Y%m%d')
#age in years
dat_age_risk$alter <- floor(time_length(difftime(referenz_datum_as_date, geburt_als_date), "years")) 
dat_age_risk <- dat_age_risk[,c("pid", "alter")]
##merging age to dataframe
dat_risk_02 <- merge(dat_risk_notincluded, dat_age_risk, by=("pid"), all.x=F, all.y = F)

#### excluding individuals with income=0
dat_risk_02 <- dat_risk_02[dat_risk_02$Brutto_imput_2018!=0,]
dim(dat_risk_02)

####logarithm of gross income
hist(dat_risk_02$Brutto_imput_2018, breaks=100)
log_brutto_risk <- log(dat_risk_02$Brutto_imput_2018) 
hist(log_brutto_risk, breaks=100) 
dat_risk_02$log_brutto_risk <- log_brutto_risk  
dat_risk <- dat_risk_02

####transfom employmentstatus into a dichotomous variable (0 = part-time, 1 = full-time)
dat_risk <- dat_risk[dat_risk$emplstatus_2018!=5,]#removing all unemployed (5) individuals from dataframe
dat_risk$emplstatus_2018[dat_risk$emplstatus_2018>1] <- 0 #recoding all part-time employments (2,3,4,6) to one category, while 1 = full-time employment
table(dat_risk$emplstatus_2018)

####recode Gender (0 = male, 1 = female)
dat_risk$Gender_2018[dat_risk$Gender_2018==1] <- 0
dat_risk$Gender_2018[dat_risk$Gender_2018==2] <- 1

####aggregated means of rivalry and admiration
dat_risk$mean_admiration <- rowMeans(dat_risk[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
dat_risk$mean_rivalry <- rowMeans(dat_risk[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

###Cronbachs alpha of narcissism in the SOEP
#admiration
psych::alpha(dat_risk[,c("narq_personality_2018", "narq_special_2018", "narq_attention_2018")])
#rivalry
psych::alpha(dat_risk[,c("narq_annoyed_2018", "narq_rivals_2018", "narq_losers_2018")])

####z-standardize independent variables
dat_risk$risk_stand <- as.numeric(scale(dat_risk$risk_2018, center = T, scale = T))
dat_risk$admiration_stand <- as.numeric(scale(dat_risk$mean_admiration, center = T, scale = T))
dat_risk$rivalry_stand <- as.numeric(scale(dat_risk$mean_rivalry, center = T, scale = T))
dat_risk$loggrossincome_stand <- as.numeric(scale(dat_risk$log_brutto_risk, center = T, scale = T))
dat_risk$age_stand <- as.numeric(scale(dat_risk$alter, center = T, scale = T))
dat_risk$gender_stand <- as.numeric(scale(dat_risk$Gender_2018, center = T, scale = T))
dat_risk$emplstatus_stand <- as.numeric(scale(dat_risk$emplstatus_2018, center = T, scale = T))

####center continuous variables for regression analysis
dat_risk$alter_zen <- scale(dat_risk$alter, center = T, scale = F)
dat_risk$loggrossincome_zen <- scale(dat_risk$log_brutto_risk, center = T, scale = F)

###########################################
##           Main analyses               ##
###########################################

####descriptive statistics: weighted means and standard deviations
num_cols <- c("Brutto_imput_2018","risk_2018","mean_admiration", "mean_rivalry","emplstatus_2018","Gender_2018", "alter","log_brutto_risk")
apply(dat_risk[,num_cols],2, function(x) w.mean(x, dat_risk$biphrf))
apply(dat_risk[,num_cols],2, function(x)w.sd(x, dat_risk$biphrf))

#weighted tables for gender and employment status
#weighted table for gender
wtd.table(x=dat_risk$Gender_2018, weights=dat_risk$biphrf)$sum.of.weights/sum(dat_risk$biphrf) #ratios
wtd.table(x=dat_risk$Gender_2018, weights=dat_risk$biphrf)$sum.of.weights/sum(dat_risk$biphrf)*nrow(dat_risk) #absolut

###Weighted correlations and p-values
weighted_cors <- wtd.cor(dat_risk[,num_cols], weight=dat_risk$biphrf)
round(weighted_cors$correlation,3)
round(weighted_cors$p.value,3)

#### Regressions
###ordered-probit for risk-taking with covariates
dat_risk_fac <- dat_risk
dat_risk_fac$risk_2018 <- as.factor(dat_risk$risk_2018)

# unstandardized + not weighted
risk_unst_notw <- polr(risk_2018 ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018,data=dat_risk_fac, method = "probit", Hess = T)
summary(risk_unst_notw)

# unstandardized + weighted
risk_unst_w <- polr(risk_2018 ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018, data=dat_risk_fac, weights=dat_risk_fac$biphrf, method = "probit", Hess = T)
summary(risk_unst_w)

# standardized + not weighted
risk_stand_notw <- polr(risk_2018 ~ admiration_stand+rivalry_stand+age_stand+gender_stand, data=dat_risk_fac, method = "probit", Hess = T)
summary(risk_stand_notw)

# standardized + weighted
risk_stand_w <- polr(risk_2018 ~ admiration_stand+rivalry_stand+age_stand+gender_stand, data=dat_risk_fac, weights=dat_risk_fac$biphrf, method = "probit", Hess = T)
summary(risk_stand_w)

###ordered-probit for risk-taking without covariates

# unstandardized + not weighted
risk_unst_notw_nc <- polr(risk_2018 ~ mean_admiration+mean_rivalry,data=dat_risk_fac, method = "probit", Hess = T)
summary(risk_unst_notw_nc)

# unstandardized + weighted
risk_unst_w_nc <- polr(risk_2018 ~ mean_admiration+mean_rivalry, data=dat_risk_fac, weights=dat_risk_fac$biphrf, method = "probit", Hess = T)
summary(risk_unst_w_nc)

# standardized + not weighted
risk_stand_notw_nc <- polr(risk_2018 ~ admiration_stand+rivalry_stand, data=dat_risk_fac, method = "probit", Hess = T)
summary(risk_stand_notw_nc)

# standardized + weighted
risk_stand_w_nc <- polr(risk_2018 ~ admiration_stand+rivalry_stand, data=dat_risk_fac, weights=dat_risk_fac$biphrf, method = "probit", Hess = T)
summary(risk_stand_w_nc)

## tables report: without covariates, with covariates, standardized, unstandardized,weighted,unweighted
# with weights
#standardized
stargazer(risk_stand_w_nc,risk_stand_w, type = "html", 
          title = "Standardized - with weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_weights_standardized_outliers_included.html")
#unstandardized
stargazer(risk_unst_w_nc,risk_unst_w, type = "html", 
          title = "Unstandardized - with weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_weights_unstandardized_outliers_included.html")

# no weights
#standardized
stargazer(risk_stand_notw_nc,risk_stand_notw, type = "html", 
          title = "Standardized - without weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_No_weights_standardized_outliers_included.html")

#unstandardized
stargazer(risk_unst_notw_nc,risk_unst_notw, type = "html", 
          title = "Unstandardized - without weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("risk-attitude"), 
          covariate.labels = c("admiration", "rivalry", "age", "female"),
          out = "Tables/table2_risk_No_weights_unstandardized_outliers_included.html")

### linear regression for income with covariates

# unstandardized + not weighted
inc_unst_notw <- lm(log_brutto_risk ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018+emplstatus_2018+risk_2018,data=dat_risk)
summary(inc_unst_notw)

# unstandardized + weighted
inc_unst_w <- lm(log_brutto_risk ~ mean_admiration+mean_rivalry+alter_zen+Gender_2018+emplstatus_2018+risk_2018, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_unst_w)

# standardized + not weighted
inc_stand_notw <- lm(log_brutto_risk ~ admiration_stand+rivalry_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk)
summary(inc_stand_notw)

# standardized + weighted
inc_stand_w <- lm(log_brutto_risk ~ admiration_stand+rivalry_stand+age_stand+gender_stand+emplstatus_stand+risk_stand, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_stand_w)

### linear regression for income without covariates
# unstandardized + not weighted
inc_unst_notw_nc <- lm(log_brutto_risk ~ mean_admiration+mean_rivalry+risk_2018,data=dat_risk)
summary(inc_unst_notw_nc)

# unstandardized + weighted
inc_unst_w_nc <- lm(log_brutto_risk ~ mean_admiration+mean_rivalry+risk_2018, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_unst_w_nc)

# standardized + not weighted
inc_stand_notw_nc <- lm(log_brutto_risk ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk)
summary(inc_stand_notw_nc)

# standardized + weighted
inc_stand_w_nc <- lm(log_brutto_risk ~ admiration_stand+rivalry_stand+risk_stand, data=dat_risk, weights=dat_risk$biphrf)
summary(inc_stand_w_nc)

## tables report: without covariates, with covariates, standardized, unstandardized,weighted,unweighted
#weights
#standardized
stargazer(inc_stand_w_nc,inc_stand_w, type = "html", 
          title = "Standardized - with weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_weights_standardized_outliers_included.html")
#unstandardized
stargazer(inc_unst_w_nc,inc_unst_w, type = "html", 
          title = "Unstandardized - with weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_weights_unstandardized_outliers_included.html")

#without weights
#standardized
stargazer(inc_stand_notw_nc,inc_stand_notw, type = "html", 
          title = "Standardized - without weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_No_weights_standardized_outliers_included.html")
#unstandardized
stargazer(inc_unst_notw_nc,inc_unst_notw, type = "html", 
          title = "Unstandardized - without weights - outliers included", 
          digits = 2, ci=T, 
          dep.var.labels = c("logged gross income"), 
          covariate.labels = c("admiration", "rivalry","age", "female", "full-time", "risk-attitude"),
          out = "Tables/table3_income_No_weights_unstandardized_outliers_included.html")


#####Mediation: admiration & rivalry mediated by risk-taking on log-income
names(dat_risk)
##predictors on mediator risk-taking
mediator_model <- lm(risk_stand ~ admiration_stand + rivalry_stand + age_stand + gender_stand + emplstatus_stand, data=dat_risk)
summary(mediator_model)
###predictors and mediator on log_income
mediator_model_on_income <- lm(loggrossincome_stand ~ admiration_stand + rivalry_stand + age_stand + gender_stand + emplstatus_stand + risk_stand, data=dat_risk )
summary(mediator_model_on_income)
###causal mediation analysis admiration#results_adm = mediation::mediate(mediator_model,mediator_model_on_income, treat= "mean_admiration", mediator = "risk_2018" )
#summary(results_adm)
#pathmodel
results_adm_riv_psy = psych::mediate(loggrossincome_stand ~ admiration_stand + rivalry_stand - age_stand - gender_stand - emplstatus_stand + (risk_stand), data=dat_risk)
summary(results_adm_riv_psy)
